powered by
This function takes a hierarchical structure of lists and extracts all atomic vectors, returning one flat list of all those vectors.
flatten_list_of_lists(x)
The list of lists.
A list of atomic vectors.
# NOT RUN { ### First create a list of lists listOfLists <- list(list(list(1:3, 8:5), 7:7), list(1:4, 8:2)); yum::flatten_list_of_lists(listOfLists); # }
Run the code above in your browser using DataLab